==> com.idenfy.idenfySdk-1.0.0-sources.jar: com/idenfy/idenfySdk/helpers/DocumentWrapper.java <==
package com.idenfy.idenfySdk.helpers;

import com.idenfy.idenfySdk.helpers.enums.DocumentType;

public class DocumentWrapper  {
    private DocumentType documentType;
    private boolean cameraViewVisibility;
    private boolean nextButtonVisibility;
    private boolean recreateButtonVisibility;
    private boolean actionButtonVisibility;
    private boolean imageInfoLayout;
    private boolean facePhotoVisibility;
    private boolean showImageLayoutVisibility;
    private boolean cropShapeImageViewVisibility;
    private boolean imageViewResultVisibility;
    private boolean imageViewFullSizeResultVisibility;
    private boolean documentTitleTutorialVisibility;
    private boolean takePictureButtonAvailability;



    public DocumentWrapper(DocumentType documentType, boolean cameraViewVisibility, boolean nextButtonVisibility, boolean recreateButtonVisibility, boolean actionButtonVisibility,
                           boolean imageInfoLayout, boolean facePhotoVisibility, boolean showImageLayoutVisibility
    , boolean cropShapeImageViewVisibility,
                           boolean imageViewFullSizeResultVisibility, boolean imageViewResultVisibility
    , boolean documentTitleTutorialVisibility
    , boolean takePictureButtonAvailability
                           ) {
        this.documentType = documentType;
        this.cameraViewVisibility = cameraViewVisibility;
        this.nextButtonVisibility = nextButtonVisibility;
        this.recreateButtonVisibility = recreateButtonVisibility;
        this.actionButtonVisibility = actionButtonVisibility;
        this.imageInfoLayout = imageInfoLayout;
        this.facePhotoVisibility = facePhotoVisibility;
        this.showImageLayoutVisibility = showImageLayoutVisibility;
        this.cropShapeImageViewVisibility = cropShapeImageViewVisibility;
        this.imageViewFullSizeResultVisibility = imageViewFullSizeResultVisibility;
        this.imageViewResultVisibility = imageViewResultVisibility;
        this.documentTitleTutorialVisibility = documentTitleTutorialVisibility;
        this.takePictureButtonAvailability = takePictureButtonAvailability;
    }

    public DocumentWrapper( boolean cameraViewVisibility, boolean nextButtonVisibility, boolean recreateButtonVisibility, boolean actionButtonVisibility,
                           boolean imageInfoLayout, boolean facePhotoVisibility, boolean showImageLayoutVisibility
            , boolean cropShapeImageViewVisibility,
                           boolean imageViewFullSizeResultVisibility, boolean imageViewResultVisibility
            , boolean documentTitleTutorialVisibility
            , boolean takePictureButtonAvailability
    ) {
        this.cameraViewVisibility = cameraViewVisibility;
        this.nextButtonVisibility = nextButtonVisibility;
        this.recreateButtonVisibility = recreateButtonVisibility;
        this.actionButtonVisibility = actionButtonVisibility;
        this.imageInfoLayout = imageInfoLayout;
        this.facePhotoVisibility = facePhotoVisibility;
        this.showImageLayoutVisibility = showImageLayoutVisibility;
        this.cropShapeImageViewVisibility = cropShapeImageViewVisibility;
        this.imageViewFullSizeResultVisibility = imageViewFullSizeResultVisibility;
        this.imageViewResultVisibility = imageViewResultVisibility;
        this.documentTitleTutorialVisibility = documentTitleTutorialVisibility;
        this.takePictureButtonAvailability = takePictureButtonAvailability;
    }


    public boolean isDocumentTitleTutorialVisibility() {
        return documentTitleTutorialVisibility;
    }

    public boolean isImageViewResultVisibility() {
        return imageViewResultVisibility;
    }

    public boolean isImageViewFullSizeResultVisibility() {
        return imageViewFullSizeResultVisibility;
    }
    public boolean isTakePictureButtonAvailability()
    {
        return takePictureButtonAvailability;
    }

    public boolean isCropShapeImageViewVisibility() {
        return cropShapeImageViewVisibility;
    }

    public boolean isShowImageLayoutVisibility() {
        return showImageLayoutVisibility;
    }

    public DocumentType getDocumentType() {
        return documentType;
    }


    public boolean isCameraViewVisibility() {
        return cameraViewVisibility;
    }

    public boolean isFacePhotoVisibility() {
        return facePhotoVisibility;
    }

    public boolean isNextButtonVisibility() {
        return nextButtonVisibility;
    }

    public boolean isRecreateButtonVisibility() {
        return recreateButtonVisibility;
    }

    public boolean isActionButtonVisibility() {
        return actionButtonVisibility;
    }
}

==> com.idenfy.idenfySdk-1.0.1-sources.jar: com/idenfy/idenfySdk/helpers/DocumentWrapper.java <==
package com.idenfy.idenfySdk.helpers;

import com.idenfy.idenfySdk.helpers.enums.DocumentType;

public class DocumentWrapper {
    private DocumentType documentType;
    private boolean cameraViewVisibility;
    private boolean nextButtonVisibility;
    private boolean recreateButtonVisibility;
    private boolean actionButtonVisibility;
    private boolean imageInfoLayout;
    private boolean facePhotoVisibility;
    private boolean showImageLayoutVisibility;
    private boolean cropShapeImageViewVisibility;
    private boolean imageViewResultVisibility;
    private boolean imageViewFullSizeResultVisibility;
    private boolean documentTitleTutorialVisibility;
    private boolean takePictureButtonAvailability;


    public DocumentWrapper(DocumentType documentType, boolean cameraViewVisibility, boolean nextButtonVisibility, boolean recreateButtonVisibility, boolean actionButtonVisibility,
                           boolean imageInfoLayout, boolean facePhotoVisibility, boolean showImageLayoutVisibility
            , boolean cropShapeImageViewVisibility,
                           boolean imageViewFullSizeResultVisibility, boolean imageViewResultVisibility
            , boolean documentTitleTutorialVisibility
            , boolean takePictureButtonAvailability
    ) {
        this.documentType = documentType;
        this.cameraViewVisibility = cameraViewVisibility;
        this.nextButtonVisibility = nextButtonVisibility;
        this.recreateButtonVisibility = recreateButtonVisibility;
        this.actionButtonVisibility = actionButtonVisibility;
        this.imageInfoLayout = imageInfoLayout;
        this.facePhotoVisibility = facePhotoVisibility;
        this.showImageLayoutVisibility = showImageLayoutVisibility;
        this.cropShapeImageViewVisibility = cropShapeImageViewVisibility;
        this.imageViewFullSizeResultVisibility = imageViewFullSizeResultVisibility;
        this.imageViewResultVisibility = imageViewResultVisibility;
        this.documentTitleTutorialVisibility = documentTitleTutorialVisibility;
        this.takePictureButtonAvailability = takePictureButtonAvailability;
    }

    public DocumentWrapper(boolean cameraViewVisibility, boolean nextButtonVisibility, boolean recreateButtonVisibility, boolean actionButtonVisibility,
                           boolean imageInfoLayout, boolean facePhotoVisibility, boolean showImageLayoutVisibility
            , boolean cropShapeImageViewVisibility,
                           boolean imageViewFullSizeResultVisibility, boolean imageViewResultVisibility
            , boolean documentTitleTutorialVisibility
            , boolean takePictureButtonAvailability
    ) {
        this.cameraViewVisibility = cameraViewVisibility;
        this.nextButtonVisibility = nextButtonVisibility;
        this.recreateButtonVisibility = recreateButtonVisibility;
        this.actionButtonVisibility = actionButtonVisibility;
        this.imageInfoLayout = imageInfoLayout;
        this.facePhotoVisibility = facePhotoVisibility;
        this.showImageLayoutVisibility = showImageLayoutVisibility;
        this.cropShapeImageViewVisibility = cropShapeImageViewVisibility;
        this.imageViewFullSizeResultVisibility = imageViewFullSizeResultVisibility;
        this.imageViewResultVisibility = imageViewResultVisibility;
        this.documentTitleTutorialVisibility = documentTitleTutorialVisibility;
        this.takePictureButtonAvailability = takePictureButtonAvailability;
    }


    public boolean isDocumentTitleTutorialVisibility() {
        return documentTitleTutorialVisibility;
    }

    public boolean isImageViewResultVisibility() {
        return imageViewResultVisibility;
    }

    public boolean isImageViewFullSizeResultVisibility() {
        return imageViewFullSizeResultVisibility;
    }

    public boolean isTakePictureButtonAvailability() {
        return takePictureButtonAvailability;
    }

    public boolean isCropShapeImageViewVisibility() {
        return cropShapeImageViewVisibility;
    }

    public boolean isShowImageLayoutVisibility() {
        return showImageLayoutVisibility;
    }

    public DocumentType getDocumentType() {
        return documentType;
    }


    public boolean isCameraViewVisibility() {
        return cameraViewVisibility;
    }

    public boolean isFacePhotoVisibility() {
        return facePhotoVisibility;
    }

    public boolean isNextButtonVisibility() {
        return nextButtonVisibility;
    }

    public boolean isRecreateButtonVisibility() {
        return recreateButtonVisibility;
    }

    public boolean isActionButtonVisibility() {
        return actionButtonVisibility;
    }
}
